pub unsafe extern "C" fn LLVMOrcGetErrorMsg(
JITStack: LLVMOrcJITStackRef,
) -> *const c_charExpand description
Get the error message for the most recent error (if any).
The returned message is owned by the ORC JIT stack.
pub unsafe extern "C" fn LLVMOrcGetErrorMsg(
JITStack: LLVMOrcJITStackRef,
) -> *const c_charGet the error message for the most recent error (if any).
The returned message is owned by the ORC JIT stack.